@@ -41,6 +41,9 @@ __all__ = (
     "FunctionCodeLocationTypeDef",
     "FunctionConfigurationTypeDef",
     "FunctionEventInvokeConfigTypeDef",
+    "ImageConfigErrorTypeDef",
+    "ImageConfigResponseTypeDef",
+    "ImageConfigTypeDef",
     "LayerTypeDef",
     "LayerVersionContentOutputTypeDef",
     "LayerVersionsListItemTypeDef",
@@ -49,6 +52,7 @@ __all__ = (
     "OnSuccessTypeDef",
     "ProvisionedConcurrencyConfigListItemTypeDef",
     "ResponseMetadata",
+    "SelfManagedEventSourceTypeDef",
     "SourceAccessConfigurationTypeDef",
     "TracingConfigResponseTypeDef",
     "VpcConfigResponseTypeDef",
@@ -195,9 +199,12 @@ EventSourceMappingConfigurationTypeDef = TypedDict(
         "Topics": List[str],
         "Queues": List[str],
         "SourceAccessConfigurations": List["SourceAccessConfigurationTypeDef"],
+        "SelfManagedEventSource": "SelfManagedEventSourceTypeDef",
         "MaximumRecordAgeInSeconds": int,
         "BisectBatchOnFunctionError": bool,
         "MaximumRetryAttempts": int,
+        "TumblingWindowInSeconds": int,
+        "FunctionResponseTypes": List[Literal["ReportBatchItemFailures"]],
     },
     total=False,
 )
@@ -205,7 +212,9 @@ EventSourceMappingConfigurationTypeDef = TypedDict(
 FileSystemConfigTypeDef = TypedDict("FileSystemConfigTypeDef", {"Arn": str, "LocalMountPath": str})
 
 FunctionCodeLocationTypeDef = TypedDict(
-    "FunctionCodeLocationTypeDef", {"RepositoryType": str, "Location": str}, total=False
+    "FunctionCodeLocationTypeDef",
+    {"RepositoryType": str, "Location": str, "ImageUri": str, "ResolvedImageUri": str},
+    total=False,
 )
 
 FunctionConfigurationTypeDef = TypedDict(
@@ -268,6 +277,9 @@ FunctionConfigurationTypeDef = TypedDict(
             "SubnetOutOfIPAddresses",
             "InvalidSubnet",
             "InvalidSecurityGroup",
+            "ImageDeleted",
+            "ImageAccessDenied",
+            "InvalidImage",
         ],
         "LastUpdateStatus": Literal["Successful", "Failed", "InProgress"],
         "LastUpdateStatusReason": str,
@@ -279,8 +291,13 @@ FunctionConfigurationTypeDef = TypedDict(
             "SubnetOutOfIPAddresses",
             "InvalidSubnet",
             "InvalidSecurityGroup",
+            "ImageDeleted",
+            "ImageAccessDenied",
+            "InvalidImage",
         ],
         "FileSystemConfigs": List["FileSystemConfigTypeDef"],
+        "PackageType": Literal["Zip", "Image"],
+        "ImageConfigResponse": "ImageConfigResponseTypeDef",
         "SigningProfileVersionArn": str,
         "SigningJobArn": str,
     },
@@ -299,6 +316,22 @@ FunctionEventInvokeConfigTypeDef = TypedDict(
     total=False,
 )
 
+ImageConfigErrorTypeDef = TypedDict(
+    "ImageConfigErrorTypeDef", {"ErrorCode": str, "Message": str}, total=False
+)
+
+ImageConfigResponseTypeDef = TypedDict(
+    "ImageConfigResponseTypeDef",
+    {"ImageConfig": "ImageConfigTypeDef", "Error": "ImageConfigErrorTypeDef"},
+    total=False,
+)
+
+ImageConfigTypeDef = TypedDict(
+    "ImageConfigTypeDef",
+    {"EntryPoint": List[str], "Command": List[str], "WorkingDirectory": str},
+    total=False,
+)
+
 LayerTypeDef = TypedDict(
     "LayerTypeDef",
     {"Arn": str, "CodeSize": int, "SigningProfileVersionArn": str, "SigningJobArn": str},
@@ -392,8 +425,25 @@ ResponseMetadata = TypedDict(
     },
 )
 
+SelfManagedEventSourceTypeDef = TypedDict(
+    "SelfManagedEventSourceTypeDef",
+    {"Endpoints": Dict[Literal["KAFKA_BOOTSTRAP_SERVERS"], List[str]]},
+    total=False,
+)
+
 SourceAccessConfigurationTypeDef = TypedDict(
-    "SourceAccessConfigurationTypeDef", {"Type": Literal["BASIC_AUTH"], "URI": str}, total=False
+    "SourceAccessConfigurationTypeDef",
+    {
+        "Type": Literal[
+            "BASIC_AUTH",
+            "VPC_SUBNET",
+            "VPC_SECURITY_GROUP",
+            "SASL_SCRAM_512_AUTH",
+            "SASL_SCRAM_256_AUTH",
+        ],
+        "URI": str,
+    },
+    total=False,
 )
 
 TracingConfigResponseTypeDef = TypedDict(
@@ -422,7 +472,13 @@ EnvironmentTypeDef = TypedDict("EnvironmentTypeDef", {"Variables": Dict[str, str
 
 FunctionCodeTypeDef = TypedDict(
     "FunctionCodeTypeDef",
-    {"ZipFile": Union[bytes, IO[bytes]], "S3Bucket": str, "S3Key": str, "S3ObjectVersion": str},
+    {
+        "ZipFile": Union[bytes, IO[bytes]],
+        "S3Bucket": str,
+        "S3Key": str,
+        "S3ObjectVersion": str,
+        "ImageUri": str,
+    },
     total=False,
 )
 
